@@ -15,11 +15,17 @@ def hashlib_transform(module):
 
 class md5(object):
   def __init__(self, value): pass
+  def digest():
+    return u''
+  def update(self, value): pass
   def hexdigest(self):
     return u''
 
 class sha1(object):
   def __init__(self, value): pass
+  def digest():
+    return u''
+  def update(self, value): pass
   def hexdigest(self):
     return u''
 
@@ -99,7 +105,7 @@ def cleanup_resources(force=False):
 def urlparse_transform(module):
     fake = ASTNGBuilder(MANAGER).string_build('''
 
-def urlparse(urlstring, default_scheme='', allow_fragments=True):
+def urlparse(url, scheme='', allow_fragments=True):
     return ParseResult()
 
 class ParseResult(object):
@@ -126,6 +132,8 @@ def subprocess_transform(module):
     fake = ASTNGBuilder(MANAGER).string_build('''
 
 class Popen(object):
+    returncode = pid = 0
+    stdin = stdout = stderr = file()
 
     def __init__(self, args, bufsize=0, executable=None,
                  stdin=None, stdout=None, stderr=None,
@@ -136,7 +144,17 @@ class Popen(object):
 
     def communicate(self, input=None):
         return ('string', 'string')
-    ''')
+    def wait(self):
+        return self.returncode
+    def poll(self):
+        return self.returncode
+    def send_signal(self, signal):
+        pass
+    def terminate(self):
+        pass
+    def kill(self):
+        pass
+   ''')
 
     for func_name, func in fake.locals.items():
         module.locals[func_name] = func
