@@ -1,19 +1,5 @@
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
-# copyright 2003-2010 Sylvain Thenault, all rights reserved.
-# contact mailto:thenault@gmail.com
 #
 # This file is part of logilab-astng.
 #
@@ -51,32 +37,34 @@ on From and Import :
 
 __docformat__ = "restructuredtext en"
 
-from logilab.astng.node_classes import (Arguments, AssAttr, Assert,
-    Assign, AssName, AugAssign, Backquote, BinOp, BoolOp, Break, CallFunc, Compare,
-    Comprehension, Const, Continue, Decorators, DelAttr, DelName, Delete,
-    Dict, Discard, Ellipsis, EmptyNode, ExceptHandler, Exec, ExtSlice, For,
-    From, Getattr, Global, If, IfExp, Import, Index, Keyword,
-    List, ListComp, Name, Pass, Print, Raise, Return, Slice, Subscript,
-    TryExcept, TryFinally, Tuple, UnaryOp, While, With, Yield, const_factory )
-from logilab.astng.scoped_nodes import Module, GenExpr, Lambda, Function, Class
+from logilab.astng.node_classes import Arguments, AssAttr, Assert, Assign, \
+    AssName, AugAssign, Backquote, BinOp, BoolOp, Break, CallFunc, Compare, \
+    Comprehension, Const, Continue, Decorators, DelAttr, DelName, Delete, \
+    Dict, Discard, Ellipsis, EmptyNode, ExceptHandler, Exec, ExtSlice, For, \
+    From, Getattr, Global, If, IfExp, Import, Index, Keyword, \
+    List, Name, Nonlocal, Pass, Print, Raise, Return, Set, Slice, Starred, Subscript, \
+    TryExcept, TryFinally, Tuple, UnaryOp, While, With, Yield, \
+    const_factory
+from logilab.astng.scoped_nodes import Module, GenExpr, Lambda, DictComp, \
+    ListComp, SetComp, Function, Class
 
 ALL_NODE_CLASSES = (
     Arguments, AssAttr, Assert, Assign, AssName, AugAssign,
     Backquote, BinOp, BoolOp, Break,
     CallFunc, Class, Compare, Comprehension, Const, Continue,
     Decorators, DelAttr, DelName, Delete,
-    Dict, Discard,
+    Dict, DictComp, Discard,
     Ellipsis, EmptyNode, ExceptHandler, Exec, ExtSlice,
     For, From, Function,
     Getattr, GenExpr, Global,
     If, IfExp, Import, Index,
     Keyword,
     Lambda, List, ListComp,
-    Name,
+    Name, Nonlocal,
     Module,
     Pass, Print,
     Raise, Return,
-    Slice, Subscript,
+    Set, SetComp, Slice, Starred, Subscript,
     TryExcept, TryFinally, Tuple,
     UnaryOp,
     While, With,
