@@ -1,7 +1,5 @@
-# copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
-# copyright 2003-2010 Sylvain Thenault, all rights reserved.
-# contact mailto:thenault@gmail.com
 #
 # This file is part of logilab-astng.
 #
@@ -31,15 +29,14 @@ from itertools import chain
 from logilab.common.compat import builtins
 from logilab.common.decorators import cached
 
-from logilab.astng import BUILTINS_MODULE
-from logilab.astng.exceptions import NotFoundError, NoDefault, \
+from logilab.astng.exceptions import NotFoundError, \
      ASTNGBuildingException, InferenceError
 from logilab.astng.node_classes import Const, DelName, DelAttr, \
-     Dict, From, List, Name, Pass, Raise, Return, Tuple, Yield, \
-     are_exclusive, LookupMixIn, const_factory as cf, unpack_infer
+     Dict, From, List, Pass, Raise, Return, Tuple, Yield, \
+     LookupMixIn, const_factory as cf, unpack_infer
 from logilab.astng.bases import NodeNG, InferenceContext, Instance,\
      YES, Generator, UnboundMethod, BoundMethod, _infer_stmts, copy_context, \
-     BUILTINS_NAME
+     BUILTINS
 from logilab.astng.mixins import FilterStmtsMixin
 from logilab.astng.bases import Statement
 from logilab.astng.manager import ASTNGManager
@@ -268,7 +265,7 @@ class Module(LocalsDictNodeNG):
         return self._scope_lookup(node, name, offset)
 
     def pytype(self):
-        return '%s.module' % BUILTINS_MODULE
+        return '%s.module' % BUILTINS
 
     def display_type(self):
         return 'Module'
@@ -481,8 +478,8 @@ class Lambda(LocalsDictNodeNG, FilterStmtsMixin):
 
     def pytype(self):
         if 'method' in self.type:
-            return '%s.instancemethod' % BUILTINS_MODULE
-        return '%s.function' % BUILTINS_MODULE
+            return '%s.instancemethod' % BUILTINS
+        return '%s.function' % BUILTINS
 
     def display_type(self):
         if 'method' in self.type:
@@ -608,14 +605,14 @@ class Function(Statement, Lambda):
         """return true if this is a generator function"""
         # XXX should be flagged, not computed
         try:
-            return self.nodes_of_class(Yield, skip_klass=Function).next()
+            return self.nodes_of_class(Yield, skip_klass=(Function, Lambda)).next()
         except StopIteration:
             return False
 
     def infer_call_result(self, caller, context=None):
         """infer what a function is returning when called"""
         if self.is_generator():
-            yield Generator(self)
+            yield Generator()
             return
         returns = self.nodes_of_class(Return, skip_klass=Function)
         for returnnode in returns:
@@ -740,8 +737,8 @@ class Class(Statement, LocalsDictNodeNG, FilterStmtsMixin):
 
     def pytype(self):
         if self.newstyle:
-            return '%s.type' % BUILTINS_MODULE
-        return '%s.classobj' % BUILTINS_MODULE
+            return '%s.type' % BUILTINS
+        return '%s.classobj' % BUILTINS
 
     def display_type(self):
         return 'Class'
@@ -872,15 +869,14 @@ class Class(Statement, LocalsDictNodeNG, FilterStmtsMixin):
         if name in self.special_attributes:
             if name == '__module__':
                 return [cf(self.root().qname())] + values
-            # FIXME : what is expected by passing the list of ancestors to cf:
-            # you can just do [cf(tuple())] + values without breaking any test
+            # FIXME: do we really need the actual list of ancestors?
+            # returning [Tuple()] + values don't break any test
             # this is ticket http://www.logilab.org/ticket/52785
-            if name == '__bases__':
-                return [cf(tuple(self.ancestors(recurs=False, context=context)))] + values
             # XXX need proper meta class handling + MRO implementation
-            if name == '__mro__' and self.newstyle:
-                # XXX mro is read-only but that's not our job to detect that
-                return [cf(tuple(self.ancestors(recurs=True, context=context)))] + values
+            if name == '__bases__' or (name == '__mro__' and self.newstyle):
+                node = Tuple()
+                node.items = self.ancestors(recurs=True, context=context)
+                return [node] + values
             return std_special_attributes(self, name)
         # don't modify the list in self.locals!
         values = list(values)
@@ -932,7 +928,7 @@ class Class(Statement, LocalsDictNodeNG, FilterStmtsMixin):
             #if self.newstyle: XXX cause an infinite recursion error
             try:
                 getattribute = self.getattr('__getattribute__', context)[0]
-                if getattribute.root().name != BUILTINS_NAME:
+                if getattribute.root().name != BUILTINS:
                     # class has a custom __getattribute__ defined
                     return True
             except NotFoundError:
