@@ -1,7 +1,5 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
-# copyright 2003-2010 Sylvain Thenault, all rights reserved.
-# contact mailto:thenault@gmail.com
 #
 # This file is part of logilab-astng.
 #
@@ -22,7 +20,7 @@ from logilab.common.testlib import TestCase, unittest_main
 import sys
 from os.path import join, abspath, dirname
 from logilab.astng.manager import ASTNGManager, _silent_no_wrap
-from logilab.astng.bases import  BUILTINS_NAME
+from logilab.astng.bases import  BUILTINS
 
 DATA = join(dirname(abspath(__file__)), 'data')
 
@@ -42,12 +40,12 @@ class ASTNGManagerTC(TestCase):
     def test_astng_from_class(self):
         astng = self.manager.astng_from_class(int)
         self.assertEqual(astng.name, 'int')
-        self.assertEqual(astng.parent.frame().name, BUILTINS_NAME)
+        self.assertEqual(astng.parent.frame().name, BUILTINS)
 
         astng = self.manager.astng_from_class(object)
         self.assertEqual(astng.name, 'object')
-        self.assertEqual(astng.parent.frame().name, BUILTINS_NAME)
-        self.failUnless('__setattr__' in astng)
+        self.assertEqual(astng.parent.frame().name, BUILTINS)
+        self.assertIn('__setattr__', astng)
 
     def _test_astng_from_zip(self, archive):
         origpath = sys.path[:]
@@ -57,7 +55,7 @@ class ASTNGManagerTC(TestCase):
         try:
             module = self.manager.astng_from_module_name('mypypa')
             self.assertEqual(module.name, 'mypypa')
-            self.failUnless(module.file.endswith('%s/mypypa' % archive),
+            self.assertTrue(module.file.endswith('%s/mypypa' % archive),
                             module.file)
         finally:
             # remove the module, else after importing egg, we don't get the zip
@@ -83,8 +81,9 @@ class ASTNGManagerTC(TestCase):
         obj = self.manager.project_from_files([DATA], _silent_no_wrap, 'data')
         expected = set(['SSL1', '__init__', 'all', 'appl', 'format', 'module',
                         'module2', 'noendingnewline', 'nonregr', 'notall'])
-        expected = ['data', 'data.SSL1', 'data.SSL1.Connection1', 'data.all',
-                    'data.appl', 'data.appl.myConnection', 'data.format',
+        expected = ['data', 'data.SSL1', 'data.SSL1.Connection1',
+                    'data.absimport', 'data.all',
+                    'data.appl', 'data.appl.myConnection', 'data.email', 'data.format',
                     'data.module', 'data.module2', 'data.noendingnewline',
                     'data.nonregr', 'data.notall']
         self.assertListEqual(sorted(k for k in obj.keys()), expected)
@@ -101,11 +100,11 @@ class BorgASTNGManagerTC(TestCase):
         """test that the ASTNGManager is really a borg, i.e. that two different
         instances has same cache"""
         first_manager = ASTNGManager()
-        built = first_manager.astng_from_module_name(BUILTINS_NAME)
+        built = first_manager.astng_from_module_name(BUILTINS)
 
         second_manager = ASTNGManager()
-        second_built = first_manager.astng_from_module_name(BUILTINS_NAME)
-        self.assertTrue(built is second_built)
+        second_built = first_manager.astng_from_module_name(BUILTINS)
+        self.assertIs(built, second_built)
 
 
 if __name__ == '__main__':
